@@ -2,14 +2,14 @@
 
 #' Stat for density joyplots
 #'
-#' This stat is the default stat used by [geom_joy]. It is very similar to [ggplot2::stat_density],
+#' This stat is the default stat used by [`geom_joy`]. It is very similar to [`stat_density`],
 #' however there are a few differences. Most importantly, the density bandwidth is chosen across
 #' the entire dataset.
 #'
 #' @param geom The geometric object to use to display the data.
 #' @param bandwidth Bandwidth used for density calculation. If not provided, is estimated from the data.
 #' @param from,to The left and right-most points of the grid at which the density is to be estimated,
-#'   as in [density()]. If not provided, there are estimated from the data range and the bandwidth.
+#'   as in [`density()`]. If not provided, there are estimated from the data range and the bandwidth.
 #' @inheritParams geom_ridgeline
 #' @importFrom ggplot2 layer
 #' @export
@@ -37,6 +37,7 @@ stat_joy <- function(mapping = NULL, data = NULL, geom = "joy",
 #' @format NULL
 #' @usage NULL
 #' @importFrom ggplot2 ggproto Stat
+#' @importFrom purrr reduce
 #' @export
 StatJoy <- ggproto("StatJoy", Stat,
   required_aes = "x",
@@ -73,7 +74,7 @@ StatJoy <- ggproto("StatJoy", Stat,
     # calculate bandwidth, min, and max for each panel separately
     panels <- split(data, data$PANEL)
     pardata <- lapply(panels, self$calc_panel_params, params)
-    pardata <- purrr::reduce(pardata, rbind)
+    pardata <- reduce(pardata, rbind)
 
     list(
       bandwidth = pardata$bandwidth,
@@ -133,6 +134,21 @@ StatJoy <- ggproto("StatJoy", Stat,
 #'    scale_fill_viridis(begin = 0.3, discrete = TRUE, option = "B") +
 #'    labs(title = "Movie lengths 1990 - 2005")
 #'
+#' count_data <- data.frame(group = rep(letters[1:5], each = 10),
+#'                          mean = rep(1:5, each = 10))
+#' count_data$group <- factor(count_data$group, levels = letters[5:1])
+#' count_data$count <- rpois(nrow(count_data), count_data$mean)
+#' ggplot(count_data, aes(x = count, y = group, group = group)) +
+#'   geom_joy2(stat = "binline", aes(fill = group), binwidth = 1, scale = 0.95) +
+#'   geom_text(stat = "bin",
+#'           aes(y = group+0.9*..count../max(..count..),
+#'           label = ifelse(..count..>0, ..count.., "")),
+#'           vjust = 1.2, size = 3, color = "white", binwidth = 1) +
+#'   theme_joy(grid = FALSE) +
+#'   scale_x_continuous(breaks = c(0:12), limits = c(-.5, 13), expand = c(0, 0)) +
+#'   scale_y_discrete(expand = c(0.01, 0)) +
+#'   scale_fill_cyclical(values = c("#0000B0", "#7070D0")) +
+#'   guides(y = "none")
 #' @export
 stat_binline <- function(mapping = NULL, data = NULL,
                      geom = "joy", position = "identity",
